@@ -51,7 +51,7 @@ cloud9.Ec2Environment(self, "Cloud9Env2",
 c9env = cloud9.Ec2Environment(self, "Cloud9Env3",
     vpc=vpc,
     subnet_selection=ec2.SubnetSelection(
-        subnet_type=ec2.SubnetType.PRIVATE
+        subnet_type=ec2.SubnetType.PRIVATE_WITH_NAT
     )
 )
 
@@ -752,12 +752,32 @@ class CloneRepository(
         return typing.cast(builtins.str, jsii.get(self, "repositoryUrl"))
 
 
+@jsii.enum(jsii_type="@aws-cdk/aws-cloud9.ConnectionType")
+class ConnectionType(enum.Enum):
+    '''(experimental) The connection type used for connecting to an Amazon EC2 environment.
+
+    :stability: experimental
+    '''
+
+    CONNECT_SSH = "CONNECT_SSH"
+    '''(experimental) Conect through SSH.
+
+    :stability: experimental
+    '''
+    CONNECT_SSM = "CONNECT_SSM"
+    '''(experimental) Connect through AWS Systems Manager.
+
+    :stability: experimental
+    '''
+
+
 @jsii.data_type(
     jsii_type="@aws-cdk/aws-cloud9.Ec2EnvironmentProps",
     jsii_struct_bases=[],
     name_mapping={
         "vpc": "vpc",
         "cloned_repositories": "clonedRepositories",
+        "connection_type": "connectionType",
         "description": "description",
         "ec2_environment_name": "ec2EnvironmentName",
         "instance_type": "instanceType",
@@ -770,6 +790,7 @@ class Ec2EnvironmentProps:
         *,
         vpc: aws_cdk.aws_ec2.IVpc,
         cloned_repositories: typing.Optional[typing.Sequence[CloneRepository]] = None,
+        connection_type: typing.Optional[ConnectionType] = None,
         description: typing.Optional[builtins.str] = None,
         ec2_environment_name: typing.Optional[builtins.str] = None,
         instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
@@ -779,6 +800,7 @@ class Ec2EnvironmentProps:
 
         :param vpc: (experimental) The VPC that AWS Cloud9 will use to communicate with the Amazon Elastic Compute Cloud (Amazon EC2) instance.
         :param cloned_repositories: (experimental) The AWS CodeCommit repository to be cloned. Default: - do not clone any repository
+        :param connection_type: (experimental) The connection type used for connecting to an Amazon EC2 environment. Valid values are: CONNECT_SSH (default) and CONNECT_SSM (connected through AWS Systems Manager) Default: - CONNECT_SSH
         :param description: (experimental) Description of the environment. Default: - no description
         :param ec2_environment_name: (experimental) Name of the environment. Default: - automatically generated name
         :param instance_type: (experimental) The type of instance to connect to the environment. Default: - t2.micro
@@ -804,7 +826,7 @@ class Ec2EnvironmentProps:
             c9env = cloud9.Ec2Environment(self, "Cloud9Env3",
                 vpc=vpc,
                 subnet_selection=ec2.SubnetSelection(
-                    subnet_type=ec2.SubnetType.PRIVATE
+                    subnet_type=ec2.SubnetType.PRIVATE_WITH_NAT
                 )
             )
             
@@ -818,6 +840,8 @@ class Ec2EnvironmentProps:
         }
         if cloned_repositories is not None:
             self._values["cloned_repositories"] = cloned_repositories
+        if connection_type is not None:
+            self._values["connection_type"] = connection_type
         if description is not None:
             self._values["description"] = description
         if ec2_environment_name is not None:
@@ -848,6 +872,19 @@ class Ec2EnvironmentProps:
         result = self._values.get("cloned_repositories")
         return typing.cast(typing.Optional[typing.List[CloneRepository]], result)
 
+    @builtins.property
+    def connection_type(self) -> typing.Optional[ConnectionType]:
+        '''(experimental) The connection type used for connecting to an Amazon EC2 environment.
+
+        Valid values are: CONNECT_SSH (default) and CONNECT_SSM (connected through AWS Systems Manager)
+
+        :default: - CONNECT_SSH
+
+        :stability: experimental
+        '''
+        result = self._values.get("connection_type")
+        return typing.cast(typing.Optional[ConnectionType], result)
+
     @builtins.property
     def description(self) -> typing.Optional[builtins.str]:
         '''(experimental) Description of the environment.
@@ -995,7 +1032,7 @@ class Ec2Environment(
         c9env = cloud9.Ec2Environment(self, "Cloud9Env3",
             vpc=vpc,
             subnet_selection=ec2.SubnetSelection(
-                subnet_type=ec2.SubnetType.PRIVATE
+                subnet_type=ec2.SubnetType.PRIVATE_WITH_NAT
             )
         )
         
@@ -1010,6 +1047,7 @@ class Ec2Environment(
         *,
         vpc: aws_cdk.aws_ec2.IVpc,
         cloned_repositories: typing.Optional[typing.Sequence[CloneRepository]] = None,
+        connection_type: typing.Optional[ConnectionType] = None,
         description: typing.Optional[builtins.str] = None,
         ec2_environment_name: typing.Optional[builtins.str] = None,
         instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
@@ -1020,6 +1058,7 @@ class Ec2Environment(
         :param id: -
         :param vpc: (experimental) The VPC that AWS Cloud9 will use to communicate with the Amazon Elastic Compute Cloud (Amazon EC2) instance.
         :param cloned_repositories: (experimental) The AWS CodeCommit repository to be cloned. Default: - do not clone any repository
+        :param connection_type: (experimental) The connection type used for connecting to an Amazon EC2 environment. Valid values are: CONNECT_SSH (default) and CONNECT_SSM (connected through AWS Systems Manager) Default: - CONNECT_SSH
         :param description: (experimental) Description of the environment. Default: - no description
         :param ec2_environment_name: (experimental) Name of the environment. Default: - automatically generated name
         :param instance_type: (experimental) The type of instance to connect to the environment. Default: - t2.micro
@@ -1030,6 +1069,7 @@ class Ec2Environment(
         props = Ec2EnvironmentProps(
             vpc=vpc,
             cloned_repositories=cloned_repositories,
+            connection_type=connection_type,
             description=description,
             ec2_environment_name=ec2_environment_name,
             instance_type=instance_type,
@@ -1108,6 +1148,7 @@ __all__ = [
     "CfnEnvironmentEC2",
     "CfnEnvironmentEC2Props",
     "CloneRepository",
+    "ConnectionType",
     "Ec2Environment",
     "Ec2EnvironmentProps",
     "IEc2Environment",
